@@ -16,7 +16,6 @@ import re
 import unittest
 
 from oslo_config import types
-from six.moves import range as compat_range
 
 
 class ConfigTypeTests(unittest.TestCase):
@@ -38,7 +37,7 @@ class ConfigTypeTests(unittest.TestCase):
         MyString()
 
 
-class TypeTestHelper(object):
+class TypeTestHelper:
     def setUp(self):
         super(TypeTestHelper, self).setUp()
         self.type_instance = self.type
@@ -93,6 +92,11 @@ class StringTypeTests(TypeTestHelper, unittest.TestCase):
         self.type_instance = types.String(quotes=True)
         self.assertConvertedValue('foo bar"', 'foo bar"')
 
+    def test_single_quote_is_invalid(self):
+        self.type_instance = types.String(quotes=True)
+        self.assertInvalid('"')
+        self.assertInvalid("'")
+
     def test_repr(self):
         t = types.String()
         self.assertEqual('String', repr(t))
@@ -596,7 +600,7 @@ class RangeTypeTests(TypeTestHelper, unittest.TestCase):
     type = types.Range()
 
     def assertRange(self, s, r1, r2, step=1):
-        self.assertEqual(list(compat_range(r1, r2, step)),
+        self.assertEqual(list(range(r1, r2, step)),
                          list(self.type_instance(s)))
 
     def test_range(self):
@@ -762,6 +766,27 @@ class HostAddressTypeTests(TypeTestHelper, unittest.TestCase):
         self.assertConvertedValue('abc.0-0', 'abc.0-0')
 
 
+class HostDomainTypeTests(TypeTestHelper, unittest.TestCase):
+    type = types.HostDomain()
+
+    def test_invalid_host_addresses(self):
+        self.assertInvalid('-1')
+        self.assertInvalid('3.14')
+        self.assertInvalid('10.0')
+        self.assertInvalid('host..name')
+        self.assertInvalid('org.10')
+        self.assertInvalid('0.0.00')
+
+    def test_valid_host_addresses(self):
+        self.assertConvertedValue('_foo', '_foo')
+        self.assertConvertedValue('host_name', 'host_name')
+        self.assertConvertedValue(
+            'overcloud-novacompute_edge1-0.internalapi.localdomain',
+            'overcloud-novacompute_edge1-0.internalapi.localdomain')
+        self.assertConvertedValue('host_01.co.uk', 'host_01.co.uk')
+        self.assertConvertedValue('_site01001', '_site01001')
+
+
 class HostnameTypeTests(TypeTestHelper, unittest.TestCase):
     type = types.Hostname()
 
@@ -792,8 +817,8 @@ class HostnameTypeTests(TypeTestHelper, unittest.TestCase):
         self.assertInvalid("h'ost'")
         self.assertInvalid("h'ost")
         self.assertInvalid("h$ost")
-        self.assertInvalid("h%ost")
         self.assertInvalid("host_01.co.uk")
+        self.assertInvalid("h%ost")
         self.assertInvalid("host;name=99")
         self.assertInvalid('___site0.1001')
         self.assertInvalid('_site01001')
@@ -804,6 +829,7 @@ class HostnameTypeTests(TypeTestHelper, unittest.TestCase):
     def test_invalid_hostnames_with_numeric_characters(self):
         self.assertInvalid("10.0.0.0")
         self.assertInvalid("3.14")
+        self.assertInvalid('___site0.1001')
         self.assertInvalid("org.10")
         self.assertInvalid('0.0.00')
 
@@ -1039,3 +1065,40 @@ class PortTypeTests(TypeTestHelper, unittest.TestCase):
         t = types.Port(max=0)
         self.assertRaises(ValueError, t, 1)
         t(0)
+
+
+class FormatSampleDefaultTests(unittest.TestCase):
+    def test_string(self):
+        t = types.String()
+        self.assertEqual([' bar '],
+                         t.format_defaults('foo', sample_default=' bar '))
+
+    def test_string_non_str(self):
+        t = types.String()
+        e = Exception('bar')
+        self.assertEqual(['bar'],
+                         t.format_defaults('', sample_default=e))
+
+    def test_string_non_str_spaces(self):
+        t = types.String()
+        e = Exception(' bar ')
+        self.assertEqual(['" bar "'],
+                         t.format_defaults('', sample_default=e))
+
+    def test_list_string(self):
+        t = types.List(item_type=types.String())
+        test_list = ['foo', Exception(' bar ')]
+        self.assertEqual(['foo," bar "'],
+                         t.format_defaults('', sample_default=test_list))
+
+    def test_list_no_type(self):
+        t = types.List()
+        test_list = ['foo', Exception(' bar ')]
+        self.assertEqual(['foo," bar "'],
+                         t.format_defaults('', sample_default=test_list))
+
+    def test_list_not_list(self):
+        t = types.List()
+        self.assertEqual(['foo'],
+                         t.format_defaults('',
+                                           sample_default=Exception('foo')))
